import { HTMLProps, IndexKey } from 'web-utility';
export type DataObject = Record<string, any>;
export declare class VNode {
    key?: IndexKey;
    ref?: (node?: Node) => any;
    text?: string;
    selector?: string;
    tagName?: string;
    is?: string;
    props?: DataObject;
    style?: HTMLProps<HTMLElement>['style'];
    children?: VNode[];
    node?: Node;
    constructor({ children, ...meta }: VNode);
    static propsMap: Partial<Record<keyof HTMLProps<HTMLLabelElement>, string>>;
    static attrsMap: Record<string, keyof HTMLProps<HTMLLabelElement>>;
    static isFragment({ key, node, children, ...rest }: VNode): boolean;
    static fromDOM(node: Node): VNode;
}
export type JsxChild = VNode | string | number | boolean | null | undefined;
export type JsxChildren = JsxChild | Array<JsxChildren>;
export type JsxProps<T extends HTMLElement> = DataObject & Pick<VNode, 'is' | 'key' | 'ref'> & Omit<HTMLProps<T>, 'children'> & {
    children?: JsxChildren;
};
declare global {
    /**
     * @see {@link https://www.typescriptlang.org/docs/handbook/jsx.html}
     */
    namespace JSX {
        type Element = VNode;
        type JSXElements = {
            [tagName in keyof HTMLElementTagNameMap]: JsxProps<HTMLElementTagNameMap[tagName]>;
        };
        interface IntrinsicElements extends JSXElements {
        }
        interface ElementAttributesProperty {
            props: {};
        }
        interface ElementChildrenAttribute {
            children: {};
        }
    }
}
